from setuptools import setup, find_packages

setup(
    name="vvf-sdk",
    version="0.0.0.1",
    author="VMware Inc.",
    description="Python bindings for vsphere foundation sdk",
    packages=find_packages(),
    install_requires=[
        # List your package dependencies here
    ],
)

